package com.qmth.distributed.print.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.bean.result.EditResult;
import com.qmth.distributed.print.business.service.TeachStudentService;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import com.qmth.teachcloud.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.List;

/**
 * @Description: 教学学生 前端控制器
 * @Author: CaoZixuan
 * @Date: 2022-02-10
 */
@Api(tags = "教学学生Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.teach}/student")
@Validated
//@Aac(strict = BOOL.FALSE, auth = BOOL.FALSE)
public class TeachStudentController {
    @Resource
    private TeachStudentService teachStudentService;

    @ApiOperation(value = "教学学生-查询")
    @RequestMapping(value = "/page", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result findTeachStudentPage(@ApiParam(value = "教学班级id", required = true) @RequestParam String teachClazzId,
                                       @ApiParam(value = "学生信息（学号、姓名）") @RequestParam(required = false) String studentInfo,
                                       @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                       @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(teachStudentService.teachStudentPage(SystemConstant.convertIdToLong(teachClazzId), studentInfo, pageNumber, pageSize));
    }

    @ApiOperation(value = "教学学生-创建教学学生")
    @RequestMapping(value = "/create", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "创建成功", response = EditResult.class)})
    public Result createTeachStudent(@ApiParam(value = "学生名称", required = true) @RequestParam String studentName,
                                     @ApiParam(value = "学生编号", required = true) @RequestParam String studentCode,
                                     @ApiParam(value = "教学班级id", required = true) @RequestParam String teachClazzId) {
        SysUser requestUser = (SysUser) ServletUtil.getRequestUser();
        if (SystemConstant.isOneNull(studentName, studentCode, teachClazzId)) {
            throw ExceptionResultEnum.ERROR.exception("缺少参数");
        }
        return ResultUtil.ok(teachStudentService.createTeachStudent(studentName, studentCode, SystemConstant.convertIdToLong(teachClazzId), requestUser));
    }

    @ApiOperation(value = "教学学生-批量删除")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "删除成功", response = EditResult.class)})
    public Result deleteTeachStudent(@ApiParam(value = "选择的要删除的学生id集合", required = true) @RequestParam List<Long> idList) {
        return ResultUtil.ok(teachStudentService.deleteTeachStudentBatch(idList));
    }
}
